=====================
python-bluetooth-mesh
=====================

.. image:: https://img.shields.io/pypi/v/bluetooth-mesh.svg
    :target: https://pypi.org/project/bluetooth-mesh
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/bluetooth-mesh.svg
    :target: https://pypi.org/project/bluetooth-mesh
    :alt: Python versions

.. image:: https://travis-ci.org/SilvairGit/python-bluetooth-mesh.svg?branch=master
    :target: https://travis-ci.org/SilvairGit/python-bluetooth-mesh
    :alt: See Build Status on Travis CI

.. image:: https://readthedocs.org/projects/python-bluetooth-mesh/badge/?version=latest
    :target: https://python-bluetooth-mesh.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Bluetooth mesh SDK for Python allows developing applications communicating with
Bluetooth mesh network using BlueZ's bluetooth-meshd.

----

What is this thing?
-------------------

https://www.bluetooth.com/specifications/mesh-specifications

https://git.kernel.org/pub/scm/bluetooth/bluez.git/tree/doc/mesh-api.txt


Installation
------------

You can install "python-bluetooth-mesh" via `pip`_ from `PyPI`_::

    $ pip install python-bluetooth-mesh


Contributing
------------
Contributions are very welcome. Tests can be run with `tox`_, please ensure
the coverage at least stays the same before you submit a pull request.


License
-------

Distributed under the terms of the `GPL-2.0`_ license, "python-bluetooth-mesh" is
free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`GPL-2.0`: http://opensource.org/licenses/GPL-2.0
.. _`file an issue`: https://github.com/SilvairGit/python-bluetooth-mesh/issues
.. _`pytest`: https://github.com/pytest-dev/pytest
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.org/project/pip/
.. _`PyPI`: https://pypi.org/project
